@@ -1,7 +1,7 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python
 
 # Large Room Example
-# Written in 2012, 2013, 2014, 2015 by Julian Marchant <onpon4@riseup.net>
+# Written in 2012-2016 by onpon4 <onpon4@riseup.net>
 #
 # To the extent possible under law, the author(s) have dedicated all
 # copyright and related and neighboring rights to this software to the
@@ -26,7 +26,7 @@ import sge
 DATA = os.path.join(os.path.dirname(__file__), "data")
 
 
-class Game(sge.Game):
+class Game(sge.dsp.Game):
     def event_key_press(self, key, char):
         if key == 'escape':
             self.end()
@@ -39,11 +39,11 @@ class Game(sge.Game):
         self.end()
 
 
-class Circle(sge.Object):
+class Circle(sge.dsp.Object):
     def __init__(self, x, y):
         super(Circle, self).__init__(x, y, 1, sprite=circle_sprite,
                                      collision_precise=True,
-                                     image_blend=sge.Color("red"),
+                                     image_blend=sge.gfx.Color("red"),
                                      image_alpha=128)
 
     def event_step(self, time_passed, delta_mult):
@@ -85,26 +85,26 @@ def main():
          collision_events_enabled=False)
 
     # Load sprites
-    circle_sprite = sge.Sprite('circle', DATA, width=32, height=32,
-                               origin_x=16, origin_y=16)
-    fence = sge.Sprite('fence', DATA)
+    circle_sprite = sge.gfx.Sprite('circle', DATA, width=32, height=32,
+                                   origin_x=16, origin_y=16)
+    fence = sge.gfx.Sprite('fence', DATA)
 
     # Load backgrounds
-    layers = [sge.BackgroundLayer(fence, 0, 0, 0, repeat_left=True,
-                                  repeat_right=True, repeat_up=True,
-                                  repeat_down=True)]
-    background = sge.Background(layers, sge.Color('white'))
+    layers = [sge.gfx.BackgroundLayer(fence, 0, 0, 0, repeat_left=True,
+                                      repeat_right=True, repeat_up=True,
+                                      repeat_down=True)]
+    background = sge.gfx.Background(layers, sge.gfx.Color('white'))
 
     # Create objects
     circle = Circle(random.randrange(0, 640), random.randrange(0, 480))
     objects =  [circle]
 
     # Create views
-    views = [sge.View(0, 0, 0, 0, 240, 240, 240, 240)]
+    views = [sge.dsp.View(0, 0, 0, 0, 240, 240, 240, 240)]
 
     # Create rooms
-    sge.game.start_room = sge.Room(objects, 640, 640, views=views,
-                                   background=background)
+    sge.game.start_room = sge.dsp.Room(objects, 640, 640, views=views,
+                                       background=background)
 
     sge.game.start()
 
